@@ -1,41 +1,48 @@
-/*===========================================================================*\
+/* ========================================================================= *
  *                                                                           *
  *                               OpenMesh                                    *
- *      Copyright (C) 2001-2015 by Computer Graphics Group, RWTH Aachen      *
- *                           www.openmesh.org                                *
+ *           Copyright (c) 2001-2015, RWTH-Aachen University                 *
+ *           Department of Computer Graphics and Multimedia                  *
+ *                          All rights reserved.                             *
+ *                            www.openmesh.org                               *
  *                                                                           *
  *---------------------------------------------------------------------------*
- *  This file is part of OpenMesh.                                           *
+ * This file is part of OpenMesh.                                            *
+ *---------------------------------------------------------------------------*
  *                                                                           *
- *  OpenMesh is free software: you can redistribute it and/or modify         *
- *  it under the terms of the GNU Lesser General Public License as           *
- *  published by the Free Software Foundation, either version 3 of           *
- *  the License, or (at your option) any later version with the              *
- *  following exceptions:                                                    *
+ * Redistribution and use in source and binary forms, with or without        *
+ * modification, are permitted provided that the following conditions        *
+ * are met:                                                                  *
  *                                                                           *
- *  If other files instantiate templates or use macros                       *
- *  or inline functions from this file, or you compile this file and         *
- *  link it with other files to produce an executable, this file does        *
- *  not by itself cause the resulting executable to be covered by the        *
- *  GNU Lesser General Public License. This exception does not however       *
- *  invalidate any other reasons why the executable file might be            *
- *  covered by the GNU Lesser General Public License.                        *
+ * 1. Redistributions of source code must retain the above copyright notice, *
+ *    this list of conditions and the following disclaimer.                  *
  *                                                                           *
- *  OpenMesh is distributed in the hope that it will be useful,              *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of           *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            *
- *  GNU Lesser General Public License for more details.                      *
+ * 2. Redistributions in binary form must reproduce the above copyright      *
+ *    notice, this list of conditions and the following disclaimer in the    *
+ *    documentation and/or other materials provided with the distribution.   *
  *                                                                           *
- *  You should have received a copy of the GNU LesserGeneral Public          *
- *  License along with OpenMesh.  If not,                                    *
- *  see <http://www.gnu.org/licenses/>.                                      *
+ * 3. Neither the name of the copyright holder nor the names of its          *
+ *    contributors may be used to endorse or promote products derived from   *
+ *    this software without specific prior written permission.               *
  *                                                                           *
- \*===========================================================================*/
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS       *
+ * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED *
+ * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A           *
+ * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER *
+ * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,  *
+ * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,       *
+ * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR        *
+ * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF    *
+ * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING      *
+ * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS        *
+ * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.              *
+ *                                                                           *
+ * ========================================================================= */
 
 /*===========================================================================*\
  *                                                                           *
- *   $Revision: 1197 $                                                         *
- *   $Date: 2015-01-15 11:19:39 +0100 (Do, 15 Jan 2015) $                   *
+ *   $Revision: 1258 $                                                         *
+ *   $Date: 2015-04-28 15:07:46 +0200 (Di, 28 Apr 2015) $                   *
  *                                                                           *
  \*===========================================================================*/
 
@@ -70,7 +77,14 @@ namespace Decimater {
 template<class Mesh>
 DecimaterT<Mesh>::DecimaterT(Mesh& _mesh) :
   BaseDecimaterT<Mesh>(_mesh),
-    mesh_(_mesh), heap_(NULL) {
+    mesh_(_mesh),
+#if __cplusplus > 199711L || defined( __GXX_EXPERIMENTAL_CXX0X__ )
+  heap_(nullptr)
+#else
+  heap_(NULL)
+#endif
+
+{
 
   // private vertex properties
   mesh_.add_property(collapse_target_);
@@ -163,7 +177,14 @@ size_t DecimaterT<Mesh>::decimate(size_t _n_collapses) {
 
   // initialize heap
   HeapInterface HI(mesh_, priority_, heap_position_);
+
+#if __cplusplus > 199711L || defined( __GXX_EXPERIMENTAL_CXX0X__ )
+  heap_ = std::unique_ptr<DeciHeap>(new DeciHeap(HI));
+#else
   heap_ = std::auto_ptr<DeciHeap>(new DeciHeap(HI));
+#endif
+
+
   heap_->reserve(mesh_.n_vertices());
 
   for (v_it = mesh_.vertices_begin(); v_it != v_end; ++v_it) {
@@ -258,7 +279,11 @@ size_t DecimaterT<Mesh>::decimate_to_faces(size_t _nv, size_t _nf) {
 
   // initialize heap
   HeapInterface HI(mesh_, priority_, heap_position_);
-  heap_ = std::auto_ptr<DeciHeap>(new DeciHeap(HI));
+  #if __cplusplus > 199711L || defined( __GXX_EXPERIMENTAL_CXX0X__ )
+    heap_ = std::unique_ptr<DeciHeap>(new DeciHeap(HI));
+  #else
+    heap_ = std::auto_ptr<DeciHeap>(new DeciHeap(HI));
+  #endif
   heap_->reserve(mesh_.n_vertices());
 
   for (v_it = mesh_.vertices_begin(); v_it != v_end; ++v_it) {
